library(shiny)
library(tidyverse)

# Exercise 4 - Following on from exercise 3, add an option to change the variable on the y axis.
# 
# 1. Change the actionButtons to a set of radioButtons containing the same options (boxplot, violinplot, barplot)
# 2. Remove the observeEvent functions and the reactive value, and move the ggplot code into the reactive expression and/or the renderPlot function.
# 3. Add a selectInput to allow the user to select between Petal.Length, Sepal.Length, Sepal.Width or  Petal.Width as the y axis variable.
# 

ui <- fluidPage(
  
  titlePanel("Exercise 4"),
  
  sidebarLayout(
    sidebarPanel(
      textInput(inputId = "plot_name", label = "Enter plot name"),
      br(),
      actionButton(inputId = "boxplot", label = "boxplot"),
      actionButton(inputId = "violinplot", label = "violinplot"),
      actionButton(inputId = "barplot", label = "barplot"),
      br(),
      checkboxInput(inputId = "add_points", label = "show data points")
    ),
    mainPanel(
      plotOutput(outputId = "iris_plot"),
    )
  ),
  #actionButton("browser", "browser")
)

server <- function(input, output, session) {
  
  plotting_object <- reactiveVal()
  
  plot_base <- reactive({
    iris %>%
      ggplot(aes(x = Species, y = Sepal.Length, fill = Species)) +
      ggtitle(input$plot_name)
      
  })
  
  observeEvent(input$boxplot, {
    
    p <- plot_base() +
      geom_boxplot()
    
    plotting_object(p)
  })
  
  observeEvent(input$barplot, {
    
    p <- plot_base() +
      geom_col()
    
    plotting_object(p)
  })
  
  observeEvent(input$violinplot, {
    
    p <- plot_base() +
      geom_violin()
    
    plotting_object(p)
  })
  
  output$iris_plot <- renderPlot({
    
    p <- plotting_object()

    if(input$add_points) {
      p + geom_jitter(width = 0.2, height = 0)
    } else {
      p
    }
  })
  
  observeEvent(input$browser, {
    browser()
  })
  
}

shinyApp(ui, server)

